@@ -39,71 +39,77 @@
 
 int main(int argc, char **argv)
 {
-	int fd, ret;
-	unsigned long int size = 0;
-	unsigned int sigs = 0;
-	long double mb;
-	const char *virname;
+    int fd, ret;
+    unsigned long int size = 0;
+    unsigned int sigs      = 0;
+    long double mb;
+    const char *virname;
     const char *filename;
-	struct cl_engine *engine;
+    struct cl_engine *engine;
     struct cl_scan_options options;
 
-    if(argc != 2) {
-	printf("Usage: %s file\n", argv[0]);
-	return 2;
+    if (argc != 2) {
+        printf("Usage: %s file\n", argv[0]);
+        return 2;
     }
 
     filename = argv[1];
 
-    if((fd = open(argv[1], O_RDONLY)) == -1) {
-	printf("Can't open file %s\n", argv[1]);
-	return 2;
+    if ((fd = open(argv[1], O_RDONLY)) == -1) {
+        printf("Can't open file %s\n", argv[1]);
+        return 2;
     }
 
-    if((ret = cl_init(CL_INIT_DEFAULT)) != CL_SUCCESS) {
-	printf("Can't initialize libclamav: %s\n", cl_strerror(ret));
-	return 2;
+    if ((ret = cl_init(CL_INIT_DEFAULT)) != CL_SUCCESS) {
+        printf("Can't initialize libclamav: %s\n", cl_strerror(ret));
+        return 2;
     }
 
-    if(!(engine = cl_engine_new())) {
-	printf("Can't create new engine\n");
-	return 2;
+    if (!(engine = cl_engine_new())) {
+        printf("Can't create new engine\n");
+        return 2;
     }
 
+    /* Example version macro usage to determine if new feature is available */
+#if defined(LIBCLAMAV_VERSION_NUM) && (LIBCLAMAV_VERSION_NUM >= 0x090400)
+    /* Example feature usage lowering max scan time to 15 seconds. */
+    cl_engine_set_num(engine, CL_ENGINE_MAX_SCANTIME, 15000);
+#endif
+
     /* load all available databases from default directory */
-    if((ret = cl_load(cl_retdbdir(), engine, &sigs, CL_DB_STDOPT)) != CL_SUCCESS) {
-	printf("cl_load: %s\n", cl_strerror(ret));
-	close(fd);
+    if ((ret = cl_load(cl_retdbdir(), engine, &sigs, CL_DB_STDOPT)) != CL_SUCCESS) {
+        printf("cl_load: %s\n", cl_strerror(ret));
+        close(fd);
         cl_engine_free(engine);
-	return 2;
+        return 2;
     }
 
     printf("Loaded %u signatures.\n", sigs);
 
     /* build engine */
-    if((ret = cl_engine_compile(engine)) != CL_SUCCESS) {
-	printf("Database initialization error: %s\n", cl_strerror(ret));;
+    if ((ret = cl_engine_compile(engine)) != CL_SUCCESS) {
+        printf("Database initialization error: %s\n", cl_strerror(ret));
         cl_engine_free(engine);
-	close(fd);
-	return 2;
+        close(fd);
+        return 2;
     }
 
     /* scan file descriptor */
     memset(&options, 0, sizeof(struct cl_scan_options));
-    options.parse |= ~0; /* enable all parsers */
+    options.parse |= ~0;                           /* enable all parsers */
     options.general |= CL_SCAN_GENERAL_HEURISTICS; /* enable heuristic alert options */
 
-    if((ret = cl_scandesc(fd, filename, &virname, &size, engine, &options)) == CL_VIRUS) {
-	printf("Virus detected: %s\n", virname);
+    if ((ret = cl_scandesc(fd, filename, &virname, &size, engine, &options)) == CL_VIRUS) {
+        printf("Virus detected: %s\n", virname);
     } else {
-	if(ret == CL_CLEAN) {
-	    printf("No virus detected.\n");
-	} else {
-	    printf("Error: %s\n", cl_strerror(ret));
-	    cl_engine_free(engine);
-	    close(fd);
-	    return 2;
-	}
+        if (ret == CL_CLEAN) {
+            printf("No virus detected.\n");
+        } else {
+            printf("Error: %s\n", cl_strerror(ret));
+            cl_engine_free(engine);
+            close(fd);
+            return 2;
+        }
     }
     close(fd);
 
