@@ -31,6 +31,6 @@ struct cli_mapped_region {
 };
 
 int asn1_load_mscat(fmap_t *map, struct cl_engine *engine);
-cl_error_t asn1_check_mscat(struct cl_engine *engine, fmap_t *map, size_t offset, unsigned int size, struct cli_mapped_region *regions, uint32_t nregions);
+cl_error_t asn1_check_mscat(struct cl_engine *engine, fmap_t *map, size_t offset, unsigned int size, struct cli_mapped_region *regions, uint32_t nregions, cli_ctx *ctx);
 
 #endif
