@@ -35,8 +35,8 @@
 #define CL_TYPENO 500
 #define MAX_EMBEDDED_OBJ 10
 
-typedef enum {
-    CL_TYPE_ANY = 0,
+typedef enum cli_file {
+    CL_TYPE_ANY        = 0,
     CL_TYPE_TEXT_ASCII = CL_TYPENO, /* X3.4, ISO-8859, non-ISO ext. ASCII */
     CL_TYPE_TEXT_UTF8,
     CL_TYPE_TEXT_UTF16LE,
@@ -87,6 +87,7 @@ typedef enum {
     CL_TYPE_HWP3,
     CL_TYPE_OOXML_HWP,
     CL_TYPE_PS,
+    CL_TYPE_EGG,
 
     /* Section for partition types */
     CL_TYPE_PART_ANY, /* unknown partition type */
@@ -94,14 +95,15 @@ typedef enum {
 
     /* bigger numbers have higher priority (in o-t-f detection) */
     CL_TYPE_MBR,
-    CL_TYPE_HTML, /* on the fly */
-    CL_TYPE_MAIL,  /* magic + on the fly */
-    CL_TYPE_SFX, /* foo SFX marker */
+    CL_TYPE_HTML,   /* on the fly */
+    CL_TYPE_MAIL,   /* magic + on the fly */
+    CL_TYPE_SFX,    /* foo SFX marker */
     CL_TYPE_ZIPSFX, /* on the fly */
     CL_TYPE_RARSFX, /* on the fly */
     CL_TYPE_7ZSFX,
     CL_TYPE_CABSFX,
     CL_TYPE_ARJSFX,
+    CL_TYPE_EGGSFX,
     CL_TYPE_NULSFT, /* on the fly */
     CL_TYPE_AUTOIT,
     CL_TYPE_ISHIELD_MSI,
@@ -117,7 +119,7 @@ typedef enum {
     CL_TYPE_MHTML,
     CL_TYPE_LNK,
 
-    CL_TYPE_OTHER, /* on-the-fly, used for target 14 (OTHER) */
+    CL_TYPE_OTHER,  /* on-the-fly, used for target 14 (OTHER) */
     CL_TYPE_IGNORED /* please don't add anything below */
 } cli_file_t;
 
