@@ -34,16 +34,16 @@
 
 /* AC scanning modes */
 #define AC_SCAN_VIR 1
-#define AC_SCAN_FT  2
+#define AC_SCAN_FT 2
 
 /* Pattern options */
-#define ACPATT_OPTION_NOOPTS   0x00
-#define ACPATT_OPTION_NOCASE   0x01
+#define ACPATT_OPTION_NOOPTS 0x00
+#define ACPATT_OPTION_NOCASE 0x01
 #define ACPATT_OPTION_FULLWORD 0x02
-#define ACPATT_OPTION_WIDE     0x04
-#define ACPATT_OPTION_ASCII    0x08
+#define ACPATT_OPTION_WIDE 0x04
+#define ACPATT_OPTION_ASCII 0x08
 
-#define ACPATT_OPTION_ONCE     0x80
+#define ACPATT_OPTION_ONCE 0x80
 
 struct cli_subsig_matches {
     uint32_t last;
@@ -53,7 +53,7 @@ struct cli_subsig_matches {
 
 struct cli_lsig_matches {
     uint32_t subsigs;
-    struct cli_subsig_matches * matches[1]; /* matches[] is variable length */ 
+    struct cli_subsig_matches *matches[1]; /* matches[] is variable length */
 };
 
 struct cli_ac_data {
@@ -109,8 +109,8 @@ struct cli_ac_patt {
 struct cli_ac_list {
     struct cli_ac_patt *me;
     union {
-	struct cli_ac_node *node;
-	struct cli_ac_list *next;
+        struct cli_ac_node *node;
+        struct cli_ac_list *next;
     };
     struct cli_ac_list *next_same;
 };
@@ -132,17 +132,17 @@ struct cli_ac_result {
 
 #include "matcher.h"
 
-int cli_ac_addpatt(struct cli_matcher *root, struct cli_ac_patt *pattern);
-int cli_ac_initdata(struct cli_ac_data *data, uint32_t partsigs, uint32_t lsigs, uint32_t reloffsigs, uint8_t tracklen);
-int lsig_sub_matched(const struct cli_matcher *root, struct cli_ac_data *mdata, uint32_t lsigid1, uint32_t lsigid2, uint32_t realoff, int partial);
-int cli_ac_chkmacro(struct cli_matcher *root, struct cli_ac_data *data, unsigned lsigid1);
+cl_error_t cli_ac_addpatt(struct cli_matcher *root, struct cli_ac_patt *pattern);
+cl_error_t cli_ac_initdata(struct cli_ac_data *data, uint32_t partsigs, uint32_t lsigs, uint32_t reloffsigs, uint8_t tracklen);
+cl_error_t lsig_sub_matched(const struct cli_matcher *root, struct cli_ac_data *mdata, uint32_t lsigid1, uint32_t lsigid2, uint32_t realoff, int partial);
+cl_error_t cli_ac_chkmacro(struct cli_matcher *root, struct cli_ac_data *data, unsigned lsigid1);
 int cli_ac_chklsig(const char *expr, const char *end, uint32_t *lsigcnt, unsigned int *cnt, uint64_t *ids, unsigned int parse_only);
 void cli_ac_freedata(struct cli_ac_data *data);
-int cli_ac_scanbuff(const unsigned char *buffer, uint32_t length, const char **virname, void **customdata, struct cli_ac_result **res, const struct cli_matcher *root, struct cli_ac_data *mdata, uint32_t offset, cli_file_t ftype, struct cli_matched_type **ftoffset, unsigned int mode, cli_ctx *ctx);
-int cli_ac_buildtrie(struct cli_matcher *root);
-int cli_ac_init(struct cli_matcher *root, uint8_t mindepth, uint8_t maxdepth, uint8_t dconf_prefiltering);
-int cli_ac_caloff(const struct cli_matcher *root, struct cli_ac_data *data, const struct cli_target_info *info);
+cl_error_t cli_ac_scanbuff(const unsigned char *buffer, uint32_t length, const char **virname, void **customdata, struct cli_ac_result **res, const struct cli_matcher *root, struct cli_ac_data *mdata, uint32_t offset, cli_file_t ftype, struct cli_matched_type **ftoffset, unsigned int mode, cli_ctx *ctx);
+cl_error_t cli_ac_buildtrie(struct cli_matcher *root);
+cl_error_t cli_ac_init(struct cli_matcher *root, uint8_t mindepth, uint8_t maxdepth, uint8_t dconf_prefiltering);
+cl_error_t cli_ac_caloff(const struct cli_matcher *root, struct cli_ac_data *data, const struct cli_target_info *info);
 void cli_ac_free(struct cli_matcher *root);
-int cli_ac_addsig(struct cli_matcher *root, const char *virname, const char *hexsig, uint8_t sigopts, uint32_t sigid, uint16_t parts, uint16_t partno, uint16_t rtype, uint16_t type, uint32_t mindist, uint32_t maxdist, const char *offset, const uint32_t *lsigid, unsigned int options);
+cl_error_t cli_ac_addsig(struct cli_matcher *root, const char *virname, const char *hexsig, uint8_t sigopts, uint32_t sigid, uint16_t parts, uint16_t partno, uint16_t rtype, uint16_t type, uint32_t mindist, uint32_t maxdist, const char *offset, const uint32_t *lsigid, unsigned int options);
 
 #endif
