@@ -1,20 +1,20 @@
 /*
  * Extract component parts of MS XML files (e.g. MS Office 2003 XML Documents)
- * 
+ *
  * Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  * Copyright (C) 2007-2013 Sourcefire, Inc.
- * 
+ *
  * Authors: Kevin Lin
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License version 2 as published by the
  * Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  * more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc., 51
  * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -47,50 +47,51 @@
 
 #define MSXML_READBUFF SCANBUFF
 
+// clang-format off
+
 static const struct key_entry msxml_keys[] = {
-    { "worddocument",       "WordDocument",       MSXML_JSON_ROOT | MSXML_JSON_ATTRIB },
-    { "workbook",           "Workbook",           MSXML_JSON_ROOT | MSXML_JSON_ATTRIB },
-
-    { "bindata",            "BinaryData",         MSXML_SCAN_B64 | MSXML_JSON_COUNT | MSXML_JSON_ROOT },
-    { "documentproperties", "DocumentProperties", MSXML_JSON_ROOT },
-    { "author",             "Author",             MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "lastauthor",         "LastAuthor",         MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "revision",           "Revision",           MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "totaltime",          "TotalTime",          MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "created",            "Created",            MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "lastsaved",          "LastSaved",          MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "pages",              "Pages",              MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "words",              "Words",              MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "characters",         "Characters",         MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "lines",              "Lines",              MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "paragraph",          "Paragraph",          MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "characterswithspaces", "CharactersWithSpaces", MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-    { "version",            "Version",            MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-
-    { "allowpng",           "AllowPNG",           MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
-
-    { "fonts",              "Fonts",              MSXML_IGNORE_ELEM },
-    { "styles",             "Styles",             MSXML_IGNORE_ELEM }
+    { "worddocument",         "WordDocument",           MSXML_JSON_ROOT | MSXML_JSON_ATTRIB },
+    { "workbook",             "Workbook",               MSXML_JSON_ROOT | MSXML_JSON_ATTRIB },
+    { "bindata",              "BinaryData",             MSXML_SCAN_B64 | MSXML_JSON_COUNT | MSXML_JSON_ROOT },
+    { "documentproperties",   "DocumentProperties",     MSXML_JSON_ROOT },
+    { "author",               "Author",                 MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "lastauthor",           "LastAuthor",             MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "revision",             "Revision",               MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "totaltime",            "TotalTime",              MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "created",              "Created",                MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "lastsaved",            "LastSaved",              MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "pages",                "Pages",                  MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "words",                "Words",                  MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "characters",           "Characters",             MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "lines",                "Lines",                  MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "paragraph",            "Paragraph",              MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "characterswithspaces", "CharactersWithSpaces",   MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "version",              "Version",                MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "allowpng",             "AllowPNG",               MSXML_JSON_WRKPTR | MSXML_JSON_VALUE },
+    { "fonts",                "Fonts",                  MSXML_IGNORE_ELEM },
+    { "styles",               "Styles",                 MSXML_IGNORE_ELEM }
 };
 static size_t num_msxml_keys = sizeof(msxml_keys) / sizeof(struct key_entry);
 
+// clang-format on
+
 static inline size_t msxml_read_cb_new_window(struct msxml_cbdata *cbdata)
 {
     const unsigned char *new_window = NULL;
     off_t new_mappos;
     size_t bytes;
 
-    if (cbdata->mappos == cbdata->map->len) {
+    if ((size_t)cbdata->mappos == cbdata->map->len) {
         cli_msxmlmsg("msxml_read_cb: fmap REALLY EOF\n");
         return 0;
     }
 
     new_mappos = cbdata->mappos + cbdata->winsize;
-    bytes = MIN(cbdata->map->len - new_mappos, MSXML_READBUFF);
+    bytes      = MIN(cbdata->map->len - new_mappos, MSXML_READBUFF);
     if (!bytes) {
-        cbdata->window = NULL;
-        cbdata->winpos = 0;
-        cbdata->mappos = cbdata->map->len;
+        cbdata->window  = NULL;
+        cbdata->winpos  = 0;
+        cbdata->mappos  = cbdata->map->len;
         cbdata->winsize = 0;
 
         cli_msxmlmsg("msxml_read_cb: fmap EOF\n");
@@ -103,9 +104,9 @@ static inline size_t msxml_read_cb_new_window(struct msxml_cbdata *cbdata)
         return -1;
     }
 
-    cbdata->window = new_window;
-    cbdata->winpos = 0;
-    cbdata->mappos = new_mappos;
+    cbdata->window  = new_window;
+    cbdata->winpos  = 0;
+    cbdata->mappos  = new_mappos;
     cbdata->winsize = bytes;
 
     cli_msxmlmsg("msxml_read_cb: acquired new window @ [%llu(+%llu)(max:%llu)]\n",
@@ -115,11 +116,12 @@ static inline size_t msxml_read_cb_new_window(struct msxml_cbdata *cbdata)
     return bytes;
 }
 
-int msxml_read_cb(void *ctx, char *buffer, int len)
+int msxml_read_cb(void *ctx, char *buffer, int buffer_len)
 {
     struct msxml_cbdata *cbdata = (struct msxml_cbdata *)ctx;
     size_t wbytes, rbytes;
     int winret;
+    size_t len = (size_t)buffer_len;
 
     cli_msxmlmsg("msxml_read_cb called\n");
 
@@ -129,7 +131,7 @@ int msxml_read_cb(void *ctx, char *buffer, int len)
             return winret;
     }
 
-    cli_msxmlmsg("msxml_read_cb: requested %d bytes from offset %llu\n", len, (long long unsigned)(cbdata->mappos+cbdata->winpos));
+    cli_msxmlmsg("msxml_read_cb: requested %zu bytes from offset %llu\n", len, (long long unsigned)(cbdata->mappos + cbdata->winpos));
 
     wbytes = 0;
     rbytes = cbdata->winsize - cbdata->winpos;
@@ -162,42 +164,42 @@ int msxml_read_cb(void *ctx, char *buffer, int len)
 #endif
 
         read_from = cbdata->window + cbdata->winpos;
-        state = &(cbdata->state);
+        state     = &(cbdata->state);
 
-        while (rbytes > 0 && wbytes < len) {
+        while ((rbytes > 0) && (wbytes < len)) {
             switch (*state) {
-            case MSXML_STATE_NORMAL:
-                if ((*read_from) == '&')
-                    *state = MSXML_STATE_ENTITY_START_1;
-                break;
-            case MSXML_STATE_ENTITY_START_1:
-                if ((*read_from) == '#')
-                    *state = MSXML_STATE_ENTITY_START_2;
-                else
-                    *state = MSXML_STATE_NORMAL;
-                break;
-            case MSXML_STATE_ENTITY_START_2:
-                if ((*read_from) == 'x')
-                    *state = MSXML_STATE_ENTITY_HEX;
-                else if (((*read_from) >= '0') && ((*read_from) <= '9'))
-                    *state = MSXML_STATE_ENTITY_DEC;
-                else
-                    *state = MSXML_STATE_NORMAL;
-                break;
-            case MSXML_STATE_ENTITY_HEX:
-                if ((((*read_from) >= '0') && ((*read_from) <= '9')) ||
-                    (((*read_from) >= 'a') && ((*read_from) <= 'f')) ||
-                    (((*read_from) >= 'A') && ((*read_from) <= 'F'))) {}
-                else
-                    *state = MSXML_STATE_ENTITY_CLOSE;
-                break;
-            case MSXML_STATE_ENTITY_DEC:
-                if (((*read_from) >= '0') && ((*read_from) <= '9')) {}
-                else
-                    *state = MSXML_STATE_ENTITY_CLOSE;
-                break;
-            default:
-                cli_errmsg("unknown *state: %d\n", *state);
+                case MSXML_STATE_NORMAL:
+                    if ((*read_from) == '&')
+                        *state = MSXML_STATE_ENTITY_START_1;
+                    break;
+                case MSXML_STATE_ENTITY_START_1:
+                    if ((*read_from) == '#')
+                        *state = MSXML_STATE_ENTITY_START_2;
+                    else
+                        *state = MSXML_STATE_NORMAL;
+                    break;
+                case MSXML_STATE_ENTITY_START_2:
+                    if ((*read_from) == 'x')
+                        *state = MSXML_STATE_ENTITY_HEX;
+                    else if (((*read_from) >= '0') && ((*read_from) <= '9'))
+                        *state = MSXML_STATE_ENTITY_DEC;
+                    else
+                        *state = MSXML_STATE_NORMAL;
+                    break;
+                case MSXML_STATE_ENTITY_HEX:
+                    if ((((*read_from) >= '0') && ((*read_from) <= '9')) ||
+                        (((*read_from) >= 'a') && ((*read_from) <= 'f')) ||
+                        (((*read_from) >= 'A') && ((*read_from) <= 'F'))) {
+                    } else
+                        *state = MSXML_STATE_ENTITY_CLOSE;
+                    break;
+                case MSXML_STATE_ENTITY_DEC:
+                    if (((*read_from) >= '0') && ((*read_from) <= '9')) {
+                    } else
+                        *state = MSXML_STATE_ENTITY_CLOSE;
+                    break;
+                default:
+                    cli_errmsg("unknown *state: %d\n", *state);
             }
 
             if (*state == MSXML_STATE_ENTITY_CLOSE) {
@@ -223,12 +225,12 @@ int msxml_read_cb(void *ctx, char *buffer, int len)
 }
 #endif
 
-int cli_scanmsxml(cli_ctx *ctx)
+cl_error_t cli_scanmsxml(cli_ctx *ctx)
 {
 #if HAVE_LIBXML2
     struct msxml_cbdata cbdata;
     xmlTextReaderPtr reader = NULL;
-    int state, ret = CL_SUCCESS;
+    cl_error_t ret          = CL_SUCCESS;
 
     cli_dbgmsg("in cli_scanmsxml()\n");
 
