@@ -22,7 +22,7 @@
  *  OpenSSL library under certain conditions as described in each
  *  individual source file, and distribute linked combinations
  *  including the two.
- *  
+ *
  *  You must obey the GNU General Public License in all respects
  *  for all of the code used other than OpenSSL.  If you modify
  *  file(s) with this exception, you may extend this exception to your
@@ -37,7 +37,7 @@
 #endif
 
 #include <stdio.h>
-#include <stddef.h> 
+#include <stddef.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <ctype.h>
@@ -45,10 +45,10 @@
 #include <fcntl.h>
 #include <stdlib.h>
 #include <errno.h>
-#ifdef	HAVE_LIMITS_H
+#ifdef HAVE_LIMITS_H
 #include <limits.h>
 #endif
-#ifdef	HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <zlib.h>
@@ -69,15 +69,14 @@
 #define PDFTOKEN_FLAG_XREF 0x1
 
 struct pdf_token {
-    uint32_t flags;    /* tracking flags */
-    uint32_t success;  /* successfully decoded filters */
-
-    uint32_t length;   /* length of current content */ /* TODO: transition to size_t */
-    uint8_t *content;  /* content stream */
+    uint32_t flags;   /* tracking flags */
+    uint32_t success; /* successfully decoded filters */
+    uint32_t length;  /* length of current content; TODO: transition to size_t */
+    uint8_t *content; /* content stream */
 };
 
 static size_t pdf_decodestream_internal(struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_dict *params, struct pdf_token *token, int fout, cl_error_t *status, struct objstm_struct *objstm);
-static cl_error_t pdf_decode_dump(struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_token *token, int lvl);
+static cl_error_t pdf_decode_dump(struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_token *token, uint32_t lvl);
 
 static cl_error_t filter_ascii85decode(struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_token *token);
 static cl_error_t filter_rldecode(struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_token *token);
@@ -88,10 +87,10 @@ static cl_error_t filter_lzwdecode(struct pdf_struct *pdf, struct pdf_obj *obj,
 
 /**
  * @brief       Wrapper function for pdf_decodestream_internal.
- * 
+ *
  * Allocate a token object to store decoded filter data.
  * Parse/decode the filter data and scan it.
- * 
+ *
  * @param pdf       Pdf context structure.
  * @param obj       The object we found the filter content in.
  * @param params    (optional) Dictionary parameters describing the filter data.
@@ -109,8 +108,8 @@ size_t pdf_decodestream(
     struct objstm_struct *objstm)
 {
     struct pdf_token *token = NULL;
-    size_t bytes_scanned = 0;
-    cli_ctx *ctx = pdf->ctx;
+    size_t bytes_scanned    = 0;
+    cli_ctx *ctx            = NULL;
 
     if (!status) {
         /* invalid args, and no way to pass back the status code */
@@ -123,8 +122,10 @@ size_t pdf_decodestream(
         goto done;
     }
 
+    ctx = pdf->ctx;
+
     if (!stream || !streamlen || fout < 0) {
-        cli_dbgmsg("pdf_decodestream: no filters or stream on obj %u %u\n", obj->id>>8, obj->id&0xff);
+        cli_dbgmsg("pdf_decodestream: no filters or stream on obj %u %u\n", obj->id >> 8, obj->id & 0xff);
         *status = CL_ENULLARG;
         goto done;
     }
@@ -150,7 +151,6 @@ size_t pdf_decodestream(
 
     token->content = cli_malloc(streamlen);
     if (!token->content) {
-        free(token);
         *status = CL_EMEM;
         goto done;
     }
@@ -191,12 +191,11 @@ done:
     /*
      * Free up the token, and token content, if any.
      */
-    if (NULL != token)
-    {
+    if (NULL != token) {
         if (NULL != token->content) {
             free(token->content);
             token->content = NULL;
-            token->length = 0;
+            token->length  = 0;
         }
         free(token);
         token = NULL;
@@ -206,10 +205,10 @@ done:
 }
 
 /**
- * @brief       Decode filter buffer data. 
- * 
+ * @brief       Decode filter buffer data.
+ *
  * Attempt to decompress, decrypt or otherwise parse it.
- * 
+ *
  * @param pdf           Pdf context structure.
  * @param obj           The object we found the filter content in.
  * @param params        (optional) Dictionary parameters describing the filter data.
@@ -223,12 +222,12 @@ static size_t pdf_decodestream_internal(
     struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_dict *params,
     struct pdf_token *token, int fout, cl_error_t *status, struct objstm_struct *objstm)
 {
-    cl_error_t vir = CL_CLEAN;
-    cl_error_t retval = CL_SUCCESS;
+    cl_error_t vir       = CL_CLEAN;
+    cl_error_t retval    = CL_SUCCESS;
     size_t bytes_scanned = 0;
-    cli_ctx *ctx = pdf->ctx;
-    const char *filter = NULL;
-    int i;
+    cli_ctx *ctx         = NULL;
+    const char *filter   = NULL;
+    uint32_t i;
 
     if (!status) {
         /* invalid args, and no way to pass back the status code */
@@ -240,9 +239,10 @@ static size_t pdf_decodestream_internal(
         *status = CL_EARG;
         goto done;
     }
-    
+
+    ctx     = pdf->ctx;
     *status = CL_SUCCESS;
-    
+
     /*
      * if pdf is decryptable, scan for CRYPT filter
      * if none, force a DECRYPT filter application
@@ -261,59 +261,59 @@ static size_t pdf_decodestream_internal(
     }
 
     for (i = 0; i < obj->numfilters; i++) {
-        switch(obj->filterlist[i]) {
-        case OBJ_FILTER_A85:
-            cli_dbgmsg("pdf_decodestream_internal: decoding [%d] => ASCII85DECODE\n", obj->filterlist[i]);
-            retval = filter_ascii85decode(pdf, obj, token);
-            break;
+        switch (obj->filterlist[i]) {
+            case OBJ_FILTER_A85:
+                cli_dbgmsg("pdf_decodestream_internal: decoding [%u] => ASCII85DECODE\n", obj->filterlist[i]);
+                retval = filter_ascii85decode(pdf, obj, token);
+                break;
 
-        case OBJ_FILTER_RL:
-            cli_dbgmsg("pdf_decodestream_internal: decoding [%d] => RLDECODE\n", obj->filterlist[i]);
-            retval = filter_rldecode(pdf, obj, token);
-            break;
+            case OBJ_FILTER_RL:
+                cli_dbgmsg("pdf_decodestream_internal: decoding [%u] => RLDECODE\n", obj->filterlist[i]);
+                retval = filter_rldecode(pdf, obj, token);
+                break;
 
-        case OBJ_FILTER_FLATE:
-            cli_dbgmsg("pdf_decodestream_internal: decoding [%d] => FLATEDECODE\n", obj->filterlist[i]);
-            retval = filter_flatedecode(pdf, obj, params, token);
-            break;
+            case OBJ_FILTER_FLATE:
+                cli_dbgmsg("pdf_decodestream_internal: decoding [%u] => FLATEDECODE\n", obj->filterlist[i]);
+                retval = filter_flatedecode(pdf, obj, params, token);
+                break;
 
-        case OBJ_FILTER_AH:
-            cli_dbgmsg("pdf_decodestream_internal: decoding [%d] => ASCIIHEXDECODE\n", obj->filterlist[i]);
-            retval = filter_asciihexdecode(pdf, obj, token);
-            break;
+            case OBJ_FILTER_AH:
+                cli_dbgmsg("pdf_decodestream_internal: decoding [%u] => ASCIIHEXDECODE\n", obj->filterlist[i]);
+                retval = filter_asciihexdecode(pdf, obj, token);
+                break;
 
-        case OBJ_FILTER_CRYPT:
-            cli_dbgmsg("pdf_decodestream_internal: decoding [%d] => CRYPT\n", obj->filterlist[i]);
-            retval = filter_decrypt(pdf, obj, params, token, 0);
-            break;
+            case OBJ_FILTER_CRYPT:
+                cli_dbgmsg("pdf_decodestream_internal: decoding [%u] => CRYPT\n", obj->filterlist[i]);
+                retval = filter_decrypt(pdf, obj, params, token, 0);
+                break;
 
-        case OBJ_FILTER_LZW:
-            cli_dbgmsg("pdf_decodestream_internal: decoding [%d] => LZWDECODE\n", obj->filterlist[i]);
-            retval = filter_lzwdecode(pdf, obj, params, token);
-            break;
+            case OBJ_FILTER_LZW:
+                cli_dbgmsg("pdf_decodestream_internal: decoding [%u] => LZWDECODE\n", obj->filterlist[i]);
+                retval = filter_lzwdecode(pdf, obj, params, token);
+                break;
 
-        case OBJ_FILTER_JPX:
-            if (!filter) filter = "JPXDECODE";
-        case OBJ_FILTER_DCT:
-            if (!filter) filter = "DCTDECODE";
-        case OBJ_FILTER_FAX:
-            if (!filter) filter = "FAXDECODE";
-        case OBJ_FILTER_JBIG2:
-            if (!filter) filter = "JBIG2DECODE";
+            case OBJ_FILTER_JPX:
+                if (!filter) filter = "JPXDECODE";
+            case OBJ_FILTER_DCT:
+                if (!filter) filter = "DCTDECODE";
+            case OBJ_FILTER_FAX:
+                if (!filter) filter = "FAXDECODE";
+            case OBJ_FILTER_JBIG2:
+                if (!filter) filter = "JBIG2DECODE";
 
-            cli_dbgmsg("pdf_decodestream_internal: unimplemented filter type [%d] => %s\n", obj->filterlist[i], filter);
-            filter = NULL;
-            retval = CL_BREAK;
-            break;
+                cli_dbgmsg("pdf_decodestream_internal: unimplemented filter type [%u] => %s\n", obj->filterlist[i], filter);
+                filter = NULL;
+                retval = CL_BREAK;
+                break;
 
-        default:
-            cli_dbgmsg("pdf_decodestream_internal: unknown filter type [%d]\n", obj->filterlist[i]);
-            retval = CL_BREAK;
-            break;
+            default:
+                cli_dbgmsg("pdf_decodestream_internal: unknown filter type [%u]\n", obj->filterlist[i]);
+                retval = CL_BREAK;
+                break;
         }
 
         if (!(token->content) || !(token->length)) {
-            cli_dbgmsg("pdf_decodestream_internal: empty content, breaking after %d (of %lu) filters\n", i, (long unsigned)(obj->numfilters));
+            cli_dbgmsg("pdf_decodestream_internal: empty content, breaking after %u (of %u) filters\n", i, obj->numfilters);
             break;
         }
 
@@ -321,24 +321,24 @@ static size_t pdf_decodestream_internal(
             if (retval == CL_VIRUS && SCAN_ALLMATCHES) {
                 vir = CL_VIRUS;
             } else {
-                const char* reason;
+                const char *reason;
 
                 switch (retval) {
-                case CL_VIRUS:
-                    *status = CL_VIRUS;
-                    reason = "detection";
-                    break;
-                case CL_BREAK:
-                    *status = CL_SUCCESS;
-                    reason = "decoding break";
-                    break;
-                default:
-                    *status = CL_EPARSE;
-                    reason = "decoding error";
-                    break;
+                    case CL_VIRUS:
+                        *status = CL_VIRUS;
+                        reason  = "detection";
+                        break;
+                    case CL_BREAK:
+                        *status = CL_SUCCESS;
+                        reason  = "decoding break";
+                        break;
+                    default:
+                        *status = CL_EPARSE;
+                        reason  = "decoding error";
+                        break;
                 }
 
-                cli_dbgmsg("pdf_decodestream_internal: stopping after %d (of %lu) filters (reason: %s)\n", i, (long unsigned)(obj->numfilters), reason);
+                cli_dbgmsg("pdf_decodestream_internal: stopping after %d (of %u) filters (reason: %s)\n", i, obj->numfilters, reason);
                 break;
             }
         }
@@ -346,13 +346,13 @@ static size_t pdf_decodestream_internal(
 
         /* Dump the stream content to a text file if keeptmp is enabled. */
         if (pdf->ctx->engine->keeptmp) {
-            if (CL_SUCCESS != pdf_decode_dump(pdf, obj, token, i+1)) {
+            if (CL_SUCCESS != pdf_decode_dump(pdf, obj, token, i + 1)) {
                 cli_errmsg("pdf_decodestream_internal: failed to write decoded stream content to temp file\n");
             }
         }
     }
 
-    if (token->success > 0) {
+    if ((token->success > 0) && (NULL != token->content)) {
         /*
          * Looks like we successfully decoded some or all of the stream filters,
          * so lets write it out to a file descriptor we scan.
@@ -371,33 +371,31 @@ static size_t pdf_decodestream_internal(
     }
 
     if ((NULL != objstm) &&
-        ((CL_SUCCESS == *status) || ((CL_VIRUS == *status) && SCAN_ALLMATCHES)))
-    {
-        int objs_found = pdf->nobjs;
+        ((CL_SUCCESS == *status) || ((CL_VIRUS == *status) && SCAN_ALLMATCHES))) {
+        unsigned int objs_found = pdf->nobjs;
 
         /*
          * The caller indicated that the decoded data is an object stream.
          * Perform experimental object stream parsing to extract objects from the stream.
          */
-        objstm->streambuf = (char*)token->content;
+        objstm->streambuf     = (char *)token->content;
         objstm->streambuf_len = (size_t)token->length;
 
         /* Take ownership of the malloc'd buffer */
         token->content = NULL;
-        token->length = 0;
+        token->length  = 0;
 
         /* Don't store the result. It's ok if some or all objects failed to parse.
            It would be far worse to add objects from a stream to the list, and then free
            the stream buffer due to an "error". */
-        if (CL_SUCCESS != pdf_find_and_parse_objs_in_objstm(pdf, objstm))
-        {
+        if (CL_SUCCESS != pdf_find_and_parse_objs_in_objstm(pdf, objstm)) {
             cli_dbgmsg("pdf_decodestream_internal: pdf_find_and_parse_objs_in_objstm failed!\n");
         }
 
         if (pdf->nobjs <= objs_found) {
             cli_dbgmsg("pdf_decodestream_internal: pdf_find_and_parse_objs_in_objstm did not find any new objects!\n");
         } else {
-            cli_dbgmsg("pdf_decodestream_internal: pdf_find_and_parse_objs_in_objstm found %d new objects.\n", pdf->nobjs - objs_found);
+            cli_dbgmsg("pdf_decodestream_internal: pdf_find_and_parse_objs_in_objstm found %u new objects.\n", pdf->nobjs - objs_found);
         }
     }
 
@@ -411,23 +409,23 @@ done:
 
 /**
  * @brief   Dump PDF filter content such as stream contents to a temp file.
- * 
+ *
  * Temp file is created in the pdf->dir directory.
  * Filename format is "pdf<pdf->files-1>_<lvl>".
- * 
+ *
  * @param pdf   Pdf context structure.
  * @param obj   The object we found the filter content in.
  * @param token The struct for the filter contents.
  * @param lvl   A unique index to distinguish the files from each other.
- * @return cl_error_t 
+ * @return cl_error_t
  */
-static cl_error_t pdf_decode_dump(struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_token *token, int lvl)
+static cl_error_t pdf_decode_dump(struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_token *token, uint32_t lvl)
 {
     char fname[1024];
     int ifd;
 
-    snprintf(fname, sizeof(fname), "%s"PATHSEP"pdf%02u_%02ui", pdf->dir, (pdf->files-1), lvl);
-    ifd = open(fname, O_RDWR|O_CREAT|O_EXCL|O_TRUNC|O_BINARY, 0600);
+    snprintf(fname, sizeof(fname), "%s" PATHSEP "pdf%02u_%02u", pdf->dir, (pdf->files - 1), lvl);
+    ifd = open(fname, O_RDWR | O_CREAT | O_EXCL | O_TRUNC | O_BINARY, 0600);
     if (ifd < 0) {
         char err[128];
 
@@ -435,7 +433,7 @@ static cl_error_t pdf_decode_dump(struct pdf_struct *pdf, struct pdf_obj *obj, s
         return CL_ETMPFILE;
     }
 
-    cli_dbgmsg("cli_pdf: decoded filter %d obj %u %u\n", lvl, obj->id>>8, obj->id&0xff);
+    cli_dbgmsg("cli_pdf: decoded filter %u obj %u %u\n", lvl, obj->id >> 8, obj->id & 0xff);
     cli_dbgmsg("         ... to %s\n", fname);
 
     if (cli_writen(ifd, token->content, token->length) != token->length) {
@@ -463,23 +461,23 @@ static cl_error_t filter_ascii85decode(struct pdf_struct *pdf, struct pdf_obj *o
     uint64_t sum = 0;
 
     /* 5:4 decoding ratio, with 1:4 expansion sequences => (4*length)+1 */
-    if (!(dptr = decoded = (uint8_t *)cli_malloc((4*remaining)+1))) {
+    if (!(dptr = decoded = (uint8_t *)cli_malloc((4 * remaining) + 1))) {
         cli_errmsg("cli_pdf: cannot allocate memory for decoded output\n");
         return CL_EMEM;
     }
 
-    if(cli_memstr((const char *)ptr, remaining, "~>", 2) == NULL)
+    if (cli_memstr((const char *)ptr, remaining, "~>", 2) == NULL)
         cli_dbgmsg("cli_pdf: no EOF marker found\n");
 
     while (remaining > 0) {
         int byte = (remaining--) ? (int)*ptr++ : EOF;
 
-        if((byte == '~') && (remaining > 0) && (*ptr == '>'))
+        if ((byte == '~') && (remaining > 0) && (*ptr == '>'))
             byte = EOF;
 
-        if(byte >= '!' && byte <= 'u') {
+        if (byte >= '!' && byte <= 'u') {
             sum = (sum * 85) + ((uint32_t)byte - '!');
-            if(++quintet == 5) {
+            if (++quintet == 5) {
                 *dptr++ = (unsigned char)(sum >> 24);
                 *dptr++ = (unsigned char)((sum >> 16) & 0xFF);
                 *dptr++ = (unsigned char)((sum >> 8) & 0xFF);
@@ -487,10 +485,10 @@ static cl_error_t filter_ascii85decode(struct pdf_struct *pdf, struct pdf_obj *o
 
                 declen += 4;
                 quintet = 0;
-                sum = 0;
+                sum     = 0;
             }
-        } else if(byte == 'z') {
-            if(quintet) {
+        } else if (byte == 'z') {
+            if (quintet) {
                 cli_dbgmsg("cli_pdf: unexpected 'z'\n");
                 rc = CL_EFORMAT;
                 break;
@@ -502,32 +500,32 @@ static cl_error_t filter_ascii85decode(struct pdf_struct *pdf, struct pdf_obj *o
             *dptr++ = '\0';
 
             declen += 4;
-        } else if(byte == EOF) {
+        } else if (byte == EOF) {
             cli_dbgmsg("cli_pdf: last quintet contains %d bytes\n", quintet);
-            if(quintet) {
+            if (quintet) {
                 int i;
 
-                if(quintet == 1) {
+                if (quintet == 1) {
                     cli_dbgmsg("cli_pdf: invalid last quintet (only 1 byte)\n");
                     rc = CL_EFORMAT;
                     break;
                 }
 
-                for(i = quintet; i < 5; i++)
+                for (i = quintet; i < 5; i++)
                     sum *= 85;
 
-                if(quintet > 1)
+                if (quintet > 1)
                     sum += (0xFFFFFF >> ((quintet - 2) * 8));
 
-                for(i = 0; i < quintet - 1; i++)
+                for (i = 0; i < quintet - 1; i++)
                     *dptr++ = (uint8_t)((sum >> (24 - 8 * i)) & 0xFF);
-                declen += quintet-1;
+                declen += quintet - 1;
             }
 
             break;
-        } else if(!isspace(byte)) {
+        } else if (!isspace(byte)) {
             cli_dbgmsg("cli_pdf: invalid character 0x%x @ %lu\n",
-                       byte & 0xFF, (unsigned long)(token->length-remaining));
+                       byte & 0xFF, (unsigned long)(token->length - remaining));
 
             rc = CL_EFORMAT;
             break;
@@ -541,13 +539,13 @@ static cl_error_t filter_ascii85decode(struct pdf_struct *pdf, struct pdf_obj *o
                    (unsigned long)declen, (unsigned long)(token->length));
 
         token->content = decoded;
-        token->length = declen;
+        token->length  = declen;
     } else {
         if (!(obj->flags & ((1 << OBJ_IMAGE) | (1 << OBJ_TRUNCATED))))
             pdfobj_flag(pdf, obj, BAD_ASCIIDECODE);
 
         cli_dbgmsg("cli_pdf: error occurred parsing byte %lu of %lu\n",
-                   (unsigned long)(token->length-remaining), (unsigned long)(token->length));
+                   (unsigned long)(token->length - remaining), (unsigned long)(token->length));
         free(decoded);
     }
     return rc;
@@ -560,9 +558,9 @@ static cl_error_t filter_rldecode(struct pdf_struct *pdf, struct pdf_obj *obj, s
     uint32_t declen = 0, capacity = 0;
 
     uint8_t *content = (uint8_t *)token->content;
-    uint32_t length = token->length;
-    uint32_t offset = 0;
-    int rc = CL_SUCCESS;
+    uint32_t length  = token->length;
+    uint32_t offset  = 0;
+    int rc           = CL_SUCCESS;
 
     UNUSEDPARAM(obj);
 
@@ -578,12 +576,12 @@ static cl_error_t filter_rldecode(struct pdf_struct *pdf, struct pdf_obj *obj, s
             /* direct copy of (srclen + 1) bytes */
             if (offset + srclen + 1 > length) {
                 cli_dbgmsg("cli_pdf: required source length (%lu) exceeds remaining length (%lu)\n",
-                           (long unsigned)(offset+srclen+1), (long unsigned)(length-offset));
+                           (long unsigned)(offset + srclen + 1), (long unsigned)(length - offset));
                 rc = CL_EFORMAT;
                 break;
             }
             if (declen + srclen + 1 > capacity) {
-                if ((rc = cli_checklimits("pdf", pdf->ctx, capacity+BUFSIZ, 0, 0)) != CL_SUCCESS)
+                if ((rc = cli_checklimits("pdf", pdf->ctx, capacity + BUFSIZ, 0, 0)) != CL_SUCCESS)
                     break;
 
                 if (!(temp = cli_realloc(decoded, capacity + BUFSIZ))) {
@@ -595,19 +593,19 @@ static cl_error_t filter_rldecode(struct pdf_struct *pdf, struct pdf_obj *obj, s
                 capacity += BUFSIZ;
             }
 
-            memcpy(decoded+declen, content+offset, srclen+1);
+            memcpy(decoded + declen, content + offset, srclen + 1);
             offset += srclen + 1;
             declen += srclen + 1;
         } else if (srclen > 128) {
             /* copy the next byte (257 - srclen) times */
             if (offset + 1 > length) {
                 cli_dbgmsg("cli_pdf: required source length (%lu) exceeds remaining length (%lu)\n",
-                           (long unsigned)(offset+srclen+1), (long unsigned)(length-offset));
+                           (long unsigned)(offset + srclen + 1), (long unsigned)(length - offset));
                 rc = CL_EFORMAT;
                 break;
             }
             if (declen + (257 - srclen) + 1 > capacity) {
-                if ((rc = cli_checklimits("pdf", pdf->ctx, capacity+BUFSIZ, 0, 0)) != CL_SUCCESS)
+                if ((rc = cli_checklimits("pdf", pdf->ctx, capacity + BUFSIZ, 0, 0)) != CL_SUCCESS)
                     break;
 
                 if (!(temp = cli_realloc(decoded, capacity + BUFSIZ))) {
@@ -619,13 +617,13 @@ static cl_error_t filter_rldecode(struct pdf_struct *pdf, struct pdf_obj *obj, s
                 capacity += BUFSIZ;
             }
 
-            memset(decoded+declen, content[offset], 257-srclen);
+            memset(decoded + declen, content[offset], 257 - srclen);
             offset++;
             declen += 257 - srclen;
         } else { /* srclen == 128 */
             /* end of data */
             cli_dbgmsg("cli_pdf: end-of-stream marker @ offset %lu (%lu bytes remaining)\n",
-                       (unsigned long)offset, (long unsigned)(token->length-offset));
+                       (unsigned long)offset, (long unsigned)(token->length - offset));
             break;
         }
     }
@@ -637,7 +635,7 @@ static cl_error_t filter_rldecode(struct pdf_struct *pdf, struct pdf_obj *obj, s
                    (unsigned long)declen, (unsigned long)(token->length));
 
         token->content = decoded;
-        token->length = declen;
+        token->length  = declen;
     } else {
         cli_dbgmsg("cli_pdf: error occurred parsing byte %lu of %lu\n",
                    (unsigned long)offset, (unsigned long)(token->length));
@@ -668,9 +666,9 @@ static cl_error_t filter_flatedecode(struct pdf_struct *pdf, struct pdf_obj *obj
     uint32_t declen = 0, capacity = 0;
 
     uint8_t *content = (uint8_t *)token->content;
-    uint32_t length = token->length;
+    uint32_t length  = token->length;
     z_stream stream;
-    int zstat, skip = 0, rc = CL_SUCCESS;
+    int zstat, rc = CL_SUCCESS;
 
     UNUSEDPARAM(params);
 
@@ -693,13 +691,13 @@ static cl_error_t filter_flatedecode(struct pdf_struct *pdf, struct pdf_obj *obj
     capacity = BUFSIZ;
 
     memset(&stream, 0, sizeof(stream));
-    stream.next_in = (Bytef *)content;
-    stream.avail_in = length;
-    stream.next_out = (Bytef *)decoded;
+    stream.next_in   = (Bytef *)content;
+    stream.avail_in  = length;
+    stream.next_out  = (Bytef *)decoded;
     stream.avail_out = BUFSIZ;
 
     zstat = inflateInit(&stream);
-    if(zstat != Z_OK) {
+    if (zstat != Z_OK) {
         cli_warnmsg("cli_pdf: inflateInit failed\n");
         free(decoded);
         return CL_EMEM;
@@ -717,13 +715,13 @@ static cl_error_t filter_flatedecode(struct pdf_struct *pdf, struct pdf_obj *obj
             length -= q - content;
             content = q;
 
-            stream.next_in = (Bytef *)content;
-            stream.avail_in = length;
-            stream.next_out = (Bytef *)decoded;
+            stream.next_in   = (Bytef *)content;
+            stream.avail_in  = length;
+            stream.next_out  = (Bytef *)decoded;
             stream.avail_out = capacity;
 
             zstat = inflateInit(&stream);
-            if(zstat != Z_OK) {
+            if (zstat != Z_OK) {
                 cli_warnmsg("cli_pdf: inflateInit failed\n");
                 free(decoded);
                 return CL_EMEM;
@@ -737,8 +735,8 @@ static cl_error_t filter_flatedecode(struct pdf_struct *pdf, struct pdf_obj *obj
 
     while (zstat == Z_OK && stream.avail_in) {
         /* extend output capacity if needed,*/
-        if(stream.avail_out == 0) {
-            if ((rc = cli_checklimits("pdf", pdf->ctx, capacity+BUFSIZ, 0, 0)) != CL_SUCCESS)
+        if (stream.avail_out == 0) {
+            if ((rc = cli_checklimits("pdf", pdf->ctx, capacity + BUFSIZ, 0, 0)) != CL_SUCCESS)
                 break;
 
             if (!(temp = cli_realloc(decoded, capacity + BUFSIZ))) {
@@ -746,8 +744,8 @@ static cl_error_t filter_flatedecode(struct pdf_struct *pdf, struct pdf_obj *obj
                 rc = CL_EMEM;
                 break;
             }
-            decoded = temp;
-            stream.next_out = decoded + capacity;
+            decoded          = temp;
+            stream.next_out  = decoded + capacity;
             stream.avail_out = BUFSIZ;
             declen += BUFSIZ;
             capacity += BUFSIZ;
@@ -761,37 +759,37 @@ static cl_error_t filter_flatedecode(struct pdf_struct *pdf, struct pdf_obj *obj
     declen += (BUFSIZ - stream.avail_out);
 
     /* error handling */
-    switch(zstat) {
-    case Z_OK:
-        cli_dbgmsg("cli_pdf: Z_OK on stream inflation completion\n");
-        /* intentional fall-through */
-    case Z_STREAM_END:
-        cli_dbgmsg("cli_pdf: inflated %lu bytes from %lu total bytes (%lu bytes remaining)\n",
-                   (unsigned long)declen, (unsigned long)(token->length), (unsigned long)(stream.avail_in));
-        break;
+    switch (zstat) {
+        case Z_OK:
+            cli_dbgmsg("cli_pdf: Z_OK on stream inflation completion\n");
+            /* intentional fall-through */
+        case Z_STREAM_END:
+            cli_dbgmsg("cli_pdf: inflated %lu bytes from %lu total bytes (%lu bytes remaining)\n",
+                       (unsigned long)declen, (unsigned long)(token->length), (unsigned long)(stream.avail_in));
+            break;
 
-    /* potentially fatal - *mostly* ignored as per older version */
-    case Z_STREAM_ERROR:
-    case Z_NEED_DICT:
-    case Z_DATA_ERROR:
-    case Z_MEM_ERROR:
-    default:
-        if(stream.msg)
-            cli_dbgmsg("cli_pdf: after writing %lu bytes, got error \"%s\" inflating PDF stream in %u %u obj\n",
-                       (unsigned long)declen, stream.msg, obj->id>>8, obj->id&0xff);
-        else
-            cli_dbgmsg("cli_pdf: after writing %lu bytes, got error %d inflating PDF stream in %u %u obj\n",
-                       (unsigned long)declen, zstat, obj->id>>8, obj->id&0xff);
+        /* potentially fatal - *mostly* ignored as per older version */
+        case Z_STREAM_ERROR:
+        case Z_NEED_DICT:
+        case Z_DATA_ERROR:
+        case Z_MEM_ERROR:
+        default:
+            if (stream.msg)
+                cli_dbgmsg("cli_pdf: after writing %lu bytes, got error \"%s\" inflating PDF stream in %u %u obj\n",
+                           (unsigned long)declen, stream.msg, obj->id >> 8, obj->id & 0xff);
+            else
+                cli_dbgmsg("cli_pdf: after writing %lu bytes, got error %d inflating PDF stream in %u %u obj\n",
+                           (unsigned long)declen, zstat, obj->id >> 8, obj->id & 0xff);
 
-        if (declen == 0) {
-            pdfobj_flag(pdf, obj, BAD_FLATESTART);
-            cli_dbgmsg("cli_pdf: no bytes were inflated.\n");
+            if (declen == 0) {
+                pdfobj_flag(pdf, obj, BAD_FLATESTART);
+                cli_dbgmsg("cli_pdf: no bytes were inflated.\n");
 
-            rc = CL_EFORMAT;
-        } else {
-            pdfobj_flag(pdf, obj, BAD_FLATE);
-        }
-        break;
+                rc = CL_EFORMAT;
+            } else {
+                pdfobj_flag(pdf, obj, BAD_FLATE);
+            }
+            break;
     }
 
     (void)inflateEnd(&stream);
@@ -800,10 +798,10 @@ static cl_error_t filter_flatedecode(struct pdf_struct *pdf, struct pdf_obj *obj
         free(token->content);
 
         token->content = decoded;
-        token->length = declen;
+        token->length  = declen;
     } else {
         cli_dbgmsg("cli_pdf: error occurred parsing byte %lu of %lu\n",
-                   (unsigned long)(length-stream.avail_in), (unsigned long)(token->length));
+                   (unsigned long)(length - stream.avail_in), (unsigned long)(token->length));
         free(decoded);
     }
 
@@ -815,23 +813,23 @@ static cl_error_t filter_asciihexdecode(struct pdf_struct *pdf, struct pdf_obj *
     uint8_t *decoded;
 
     const uint8_t *content = (uint8_t *)token->content;
-    uint32_t length = token->length;
+    uint32_t length        = token->length;
     uint32_t i, j;
     cl_error_t rc = CL_SUCCESS;
 
-    if (!(decoded = (uint8_t *)cli_calloc(length/2 + 1, sizeof(uint8_t)))) {
+    if (!(decoded = (uint8_t *)cli_calloc(length / 2 + 1, sizeof(uint8_t)))) {
         cli_errmsg("cli_pdf: cannot allocate memory for decoded output\n");
         return CL_EMEM;
     }
 
-    for (i = 0, j = 0; i+1 < length; i++) {
+    for (i = 0, j = 0; i + 1 < length; i++) {
         if (content[i] == ' ')
             continue;
 
         if (content[i] == '>')
             break;
 
-        if (cli_hex2str_to((const char *)content+i, (char *)decoded+j, 2) == -1) {
+        if (cli_hex2str_to((const char *)content + i, (char *)decoded + j, 2) == -1) {
             if (length - i < 4)
                 continue;
 
@@ -850,7 +848,7 @@ static cl_error_t filter_asciihexdecode(struct pdf_struct *pdf, struct pdf_obj *
                    (unsigned long)j, (unsigned long)(token->length));
 
         token->content = decoded;
-        token->length = j;
+        token->length  = j;
     } else {
         if (!(obj->flags & ((1 << OBJ_IMAGE) | (1 << OBJ_TRUNCATED))))
             pdfobj_flag(pdf, obj, BAD_ASCIIDECODE);
@@ -866,7 +864,7 @@ static cl_error_t filter_asciihexdecode(struct pdf_struct *pdf, struct pdf_obj *
 static cl_error_t filter_decrypt(struct pdf_struct *pdf, struct pdf_obj *obj, struct pdf_dict *params, struct pdf_token *token, int mode)
 {
     char *decrypted;
-    size_t length = (size_t)token->length;
+    size_t length       = (size_t)token->length;
     enum enc_method enc = ENC_IDENTITY;
 
     if (mode)
@@ -900,10 +898,9 @@ static cl_error_t filter_decrypt(struct pdf_struct *pdf, struct pdf_obj *obj, st
     cli_dbgmsg("cli_pdf: decrypted %zu bytes from %u total bytes\n",
                length, token->length);
 
-
     free(token->content);
     token->content = (uint8_t *)decrypted;
-    token->length = (uint32_t)length; /* this may truncate unfortunately, TODO: use 64-bit values internally? */
+    token->length  = (uint32_t)length; /* this may truncate unfortunately, TODO: use 64-bit values internally? */
     return CL_SUCCESS;
 }
 
@@ -913,9 +910,9 @@ static cl_error_t filter_lzwdecode(struct pdf_struct *pdf, struct pdf_obj *obj,
     uint32_t declen = 0, capacity = 0;
 
     uint8_t *content = (uint8_t *)token->content;
-    uint32_t length = token->length;
+    uint32_t length  = token->length;
     lzw_stream stream;
-    int echg = 1, lzwstat, skip = 0, rc = CL_SUCCESS;
+    int echg = 1, lzwstat, rc = CL_SUCCESS;
 
     if (pdf->ctx && !(pdf->ctx->dconf->other & OTHER_CONF_LZW))
         return CL_BREAK;
@@ -960,15 +957,15 @@ static cl_error_t filter_lzwdecode(struct pdf_struct *pdf, struct pdf_obj *obj,
     capacity = BUFSIZ;
 
     memset(&stream, 0, sizeof(stream));
-    stream.next_in = content;
-    stream.avail_in = length;
-    stream.next_out = decoded;
+    stream.next_in   = content;
+    stream.avail_in  = length;
+    stream.next_out  = decoded;
     stream.avail_out = BUFSIZ;
     if (echg)
         stream.flags |= LZW_FLAG_EARLYCHG;
 
     lzwstat = lzwInit(&stream);
-    if(lzwstat != Z_OK) {
+    if (lzwstat != Z_OK) {
         cli_warnmsg("cli_pdf: lzwInit failed\n");
         free(decoded);
         return CL_EMEM;
@@ -986,13 +983,13 @@ static cl_error_t filter_lzwdecode(struct pdf_struct *pdf, struct pdf_obj *obj,
             length -= q - content;
             content = q;
 
-            stream.next_in = (Bytef *)content;
-            stream.avail_in = length;
-            stream.next_out = (Bytef *)decoded;
+            stream.next_in   = (Bytef *)content;
+            stream.avail_in  = length;
+            stream.next_out  = (Bytef *)decoded;
             stream.avail_out = capacity;
 
             lzwstat = lzwInit(&stream);
-            if(lzwstat != Z_OK) {
+            if (lzwstat != Z_OK) {
                 cli_warnmsg("cli_pdf: lzwInit failed\n");
                 free(decoded);
                 return CL_EMEM;
@@ -1006,8 +1003,8 @@ static cl_error_t filter_lzwdecode(struct pdf_struct *pdf, struct pdf_obj *obj,
 
     while (lzwstat == Z_OK && stream.avail_in) {
         /* extend output capacity if needed,*/
-        if(stream.avail_out == 0) {
-            if ((rc = cli_checklimits("pdf", pdf->ctx, capacity+BUFSIZ, 0, 0)) != CL_SUCCESS)
+        if (stream.avail_out == 0) {
+            if ((rc = cli_checklimits("pdf", pdf->ctx, capacity + BUFSIZ, 0, 0)) != CL_SUCCESS)
                 break;
 
             if (!(temp = cli_realloc(decoded, capacity + BUFSIZ))) {
@@ -1015,8 +1012,8 @@ static cl_error_t filter_lzwdecode(struct pdf_struct *pdf, struct pdf_obj *obj,
                 rc = CL_EMEM;
                 break;
             }
-            decoded = temp;
-            stream.next_out = decoded + capacity;
+            decoded          = temp;
+            stream.next_out  = decoded + capacity;
             stream.avail_out = BUFSIZ;
             declen += BUFSIZ;
             capacity += BUFSIZ;
@@ -1030,38 +1027,38 @@ static cl_error_t filter_lzwdecode(struct pdf_struct *pdf, struct pdf_obj *obj,
     declen += (BUFSIZ - stream.avail_out);
 
     /* error handling */
-    switch(lzwstat) {
-    case LZW_OK:
-        cli_dbgmsg("cli_pdf: LZW_OK on stream inflation completion\n");
-        /* intentional fall-through */
-    case LZW_STREAM_END:
-        cli_dbgmsg("cli_pdf: inflated %lu bytes from %lu total bytes (%lu bytes remaining)\n",
-                   (unsigned long)declen, (unsigned long)(token->length), (unsigned long)(stream.avail_in));
-        break;
+    switch (lzwstat) {
+        case LZW_OK:
+            cli_dbgmsg("cli_pdf: LZW_OK on stream inflation completion\n");
+            /* intentional fall-through */
+        case LZW_STREAM_END:
+            cli_dbgmsg("cli_pdf: inflated %lu bytes from %lu total bytes (%lu bytes remaining)\n",
+                       (unsigned long)declen, (unsigned long)(token->length), (unsigned long)(stream.avail_in));
+            break;
 
-    /* potentially fatal - *mostly* ignored as per older version */
-    case LZW_STREAM_ERROR:
-    case LZW_DATA_ERROR:
-    case LZW_MEM_ERROR:
-    case LZW_BUF_ERROR:
-    case LZW_DICT_ERROR:
-    default:
-        if(stream.msg)
-            cli_dbgmsg("cli_pdf: after writing %lu bytes, got error \"%s\" inflating PDF stream in %u %u obj\n",
-                       (unsigned long)declen, stream.msg, obj->id>>8, obj->id&0xff);
-        else
-            cli_dbgmsg("cli_pdf: after writing %lu bytes, got error %d inflating PDF stream in %u %u obj\n",
-                       (unsigned long)declen, lzwstat, obj->id>>8, obj->id&0xff);
+        /* potentially fatal - *mostly* ignored as per older version */
+        case LZW_STREAM_ERROR:
+        case LZW_DATA_ERROR:
+        case LZW_MEM_ERROR:
+        case LZW_BUF_ERROR:
+        case LZW_DICT_ERROR:
+        default:
+            if (stream.msg)
+                cli_dbgmsg("cli_pdf: after writing %lu bytes, got error \"%s\" inflating PDF stream in %u %u obj\n",
+                           (unsigned long)declen, stream.msg, obj->id >> 8, obj->id & 0xff);
+            else
+                cli_dbgmsg("cli_pdf: after writing %lu bytes, got error %d inflating PDF stream in %u %u obj\n",
+                           (unsigned long)declen, lzwstat, obj->id >> 8, obj->id & 0xff);
 
-        if (declen == 0) {
-            pdfobj_flag(pdf, obj, BAD_FLATESTART);
-            cli_dbgmsg("cli_pdf: no bytes were inflated.\n");
+            if (declen == 0) {
+                pdfobj_flag(pdf, obj, BAD_FLATESTART);
+                cli_dbgmsg("cli_pdf: no bytes were inflated.\n");
 
-            rc = CL_EFORMAT;
-        } else {
-            pdfobj_flag(pdf, obj, BAD_FLATE);
-        }
-        break;
+                rc = CL_EFORMAT;
+            } else {
+                pdfobj_flag(pdf, obj, BAD_FLATE);
+            }
+            break;
     }
 
     (void)lzwInflateEnd(&stream);
@@ -1070,10 +1067,10 @@ static cl_error_t filter_lzwdecode(struct pdf_struct *pdf, struct pdf_obj *obj,
         free(token->content);
 
         token->content = decoded;
-        token->length = declen;
+        token->length  = declen;
     } else {
         cli_dbgmsg("cli_pdf: error occurred parsing byte %lu of %lu\n",
-                   (unsigned long)(length-stream.avail_in), (unsigned long)(token->length));
+                   (unsigned long)(length - stream.avail_in), (unsigned long)(token->length));
         free(decoded);
     }
 
