@@ -23,10 +23,11 @@
 #define __PE_ICONS_H
 #include "pe.h"
 
-int cli_scanicon(icon_groupset *set, uint32_t resdir_rva, cli_ctx *ctx, struct cli_exe_section *exe_sections, uint16_t nsections, uint32_t hdr_size);
+int cli_scanicon(icon_groupset *set, cli_ctx *ctx, struct cli_exe_info *peinfo);
 
 void cli_icongroupset_add(const char *groupname, icon_groupset *set, unsigned int type, cli_ctx *ctx);
-static inline void cli_icongroupset_init(icon_groupset *set) {
+static inline void cli_icongroupset_init(icon_groupset *set)
+{
     set->v[0][0] = 0;
     set->v[0][1] = 0;
     set->v[0][2] = 0;
@@ -37,5 +38,4 @@ static inline void cli_icongroupset_init(icon_groupset *set) {
     set->v[1][3] = 0;
 }
 
-
 #endif
