@@ -113,8 +113,8 @@ static cl_error_t unz(
     char name[1024], obuf[BUFSIZ];
     char *tempfile = name;
     int out_file, ret = CL_CLEAN;
-    int res              = 1;
-    unsigned int written = 0;
+    int res        = 1;
+    size_t written = 0;
 
     if (tmpd) {
         snprintf(name, sizeof(name), "%s" PATHSEP "zip.%03u", tmpd, *num_files_unzipped);
@@ -143,7 +143,7 @@ static cl_error_t unz(
                     cli_dbgmsg("cli_unzip: trimming output size to maxfilesize (%lu)\n", (long unsigned int)ctx->engine->maxfilesize);
                     csize = ctx->engine->maxfilesize;
                 }
-                if (cli_writen(out_file, src, csize) != (int)csize)
+                if (cli_writen(out_file, src, csize) != csize)
                     ret = CL_EWRITE;
                 else
                     res = 0;
@@ -208,7 +208,7 @@ static cl_error_t unz(
                         res = Z_STREAM_END;
                         break;
                     }
-                    if (cli_writen(out_file, obuf, sizeof(obuf) - (*avail_out)) != (int)(sizeof(obuf) - (*avail_out))) {
+                    if (cli_writen(out_file, obuf, sizeof(obuf) - (*avail_out)) != (size_t)(sizeof(obuf) - (*avail_out))) {
                         cli_warnmsg("cli_unzip: falied to write %lu inflated bytes\n", (unsigned long int)sizeof(obuf) - (*avail_out));
                         ret = CL_EWRITE;
                         res = 100;
@@ -251,7 +251,7 @@ static cl_error_t unz(
                         res = BZ_STREAM_END;
                         break;
                     }
-                    if (cli_writen(out_file, obuf, sizeof(obuf) - strm.avail_out) != (int)(sizeof(obuf) - strm.avail_out)) {
+                    if (cli_writen(out_file, obuf, sizeof(obuf) - strm.avail_out) != (size_t)(sizeof(obuf) - strm.avail_out)) {
                         cli_warnmsg("cli_unzip: falied to write %lu bunzipped bytes\n", (long unsigned int)sizeof(obuf) - strm.avail_out);
                         ret = CL_EWRITE;
                         res = 100;
@@ -287,7 +287,7 @@ static cl_error_t unz(
                         res = 0;
                         break;
                     }
-                    if (cli_writen(out_file, obuf, sizeof(obuf) - strm.avail_out) != (int)(sizeof(obuf) - strm.avail_out)) {
+                    if (cli_writen(out_file, obuf, sizeof(obuf) - strm.avail_out) != (size_t)(sizeof(obuf) - strm.avail_out)) {
                         cli_warnmsg("cli_unzip: falied to write %lu exploded bytes\n", (unsigned long int)sizeof(obuf) - strm.avail_out);
                         ret = CL_EWRITE;
                         res = 100;
@@ -482,7 +482,7 @@ static inline cl_error_t zdecrypt(
         if (v) {
             char name[1024], obuf[BUFSIZ];
             char *tempfile = name;
-            unsigned int written = 0, total = 0;
+            size_t written = 0, total = 0;
             fmap_t *dcypt_map;
             const uint8_t *dcypt_zip;
             int out_file;
@@ -508,7 +508,7 @@ static inline cl_error_t zdecrypt(
 
                 written++;
                 if (written >= BUFSIZ) {
-                    if (cli_writen(out_file, obuf, written) != (int)written) {
+                    if (cli_writen(out_file, obuf, written) != written) {
                         ret = CL_EWRITE;
                         goto zd_clean;
                     }
@@ -517,7 +517,7 @@ static inline cl_error_t zdecrypt(
                 }
             }
             if (written) {
-                if (cli_writen(out_file, obuf, written) != (int)written) {
+                if (cli_writen(out_file, obuf, written) != written) {
                     ret = CL_EWRITE;
                     goto zd_clean;
                 }
@@ -525,7 +525,7 @@ static inline cl_error_t zdecrypt(
                 written = 0;
             }
 
-            cli_dbgmsg("cli_unzip: decrypt - decrypted %u bytes to %s\n", total, tempfile);
+            cli_dbgmsg("cli_unzip: decrypt - decrypted %zu bytes to %s\n", total, tempfile);
 
             /* decrypt data to new fmap -> buffer */
             if (!(dcypt_map = fmap(out_file, 0, total))) {
